# Hack4U Academy Courses Library

Una biblioteca Python para consultar cursos de la academia Hack4U.

## Cursos disponibles:
- Introducción a Linux [15 horas]
- Personalizacion de Ltnux [3 noras
- Introduccion al Hacking [53 horasil

## Instalación

Instala el paquete usando 'pip3':

```python3

pip3 install hack4u

```
## Uso básico

### Listar todos las cursos

```python

from hack4u import list_courses

for course in list_courses():
    print( course)

```
### Obtener un curso por nombre

```python

from hack import get_course_by name

course = get_course_by_ name( "Introducción a Linux")
    print(course)

```

### Calcular duración total de los cursos

```python3
from hack4u.utils import total_duration
print(f"Duración total: {total _duration()} horas")

```

